const MODULE_NAME = 'PARTNER-LISTENER.ROUTERS.PRODUCT-TREE';

const axios = require('axios').default;
const express = require('express');
const urlJoin = require('url-join');

const coreUrl = require('komodo-sdk/core-url');
const logger = require('tektrans-logger');

const getFromBodyQsParams = require('../../get-from-body-qs-params');

const CORE_ENDPOINT = urlJoin(coreUrl, '/product-tree');

const router = express.Router();
module.exports = router;

const mainHandler = async (req, res) => {
    const { xid } = res.locals;

    const terminalName = getFromBodyQsParams(req, 'terminal_name');
    const password = getFromBodyQsParams(req, 'password');

    try {
        const result = await axios.get(CORE_ENDPOINT, {
            params: {
                terminal_name: terminalName,
                password,
            },
        });

        if (!result) {
            const e = new Error(`${MODULE_NAME} B7555411: Invalid result from CORE`);
            throw e;
        }

        result.httpgetx_xid = xid;
        res.json(result);
    } catch (e) {
        logger.warn(`${MODULE_NAME} 5AA99A06: Exception`, {
            xid,
            eCode: e.code,
            eMessage: e.message || e,
        });

        res.json({
            xid,
            ts: new Date(),
            error: e.message || e,
        });
    }
};

router.get('/', mainHandler);
